@@ -6,22 +6,28 @@
 /* .Call calls */
 extern SEXP cpbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP clbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP cmbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP cmbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP cpwbart(SEXP, SEXP, SEXP);
 extern SEXP cwbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP cgbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP mc_cores_openmp();
+extern SEXP crtnorm(SEXP, SEXP, SEXP);
+extern SEXP cdraw_lambda_i(SEXP, SEXP, SEXP, SEXP);
 //extern SEXP cdpmbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 //extern SEXP cdpmwbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"cpbart",  (DL_FUNC) &cpbart,  27},
     {"clbart",  (DL_FUNC) &clbart,  24},
-    {"cmbart",  (DL_FUNC) &cmbart,  25},
+    {"cmbart",  (DL_FUNC) &cmbart,  28},
     {"cpwbart", (DL_FUNC) &cpwbart,  3},
     {"cwbart",  (DL_FUNC) &cwbart,  31},
+    {"cgbart",  (DL_FUNC) &cgbart,  30},
+    {"mc_cores_openmp",(DL_FUNC) &mc_cores_openmp,0},
+    {"crtnorm", (DL_FUNC) &crtnorm, 3},
+    {"cdraw_lambda_i", (DL_FUNC) &cdraw_lambda_i, 4},
 //    {"cdpmbart",(DL_FUNC) &cdpmbart,25},
 //    {"cdpmwbart",(DL_FUNC) &cdpmwbart,27},
-    {"mc_cores_openmp",(DL_FUNC) &mc_cores_openmp,0},
     {NULL, NULL, 0}
 };
 
